"""
Code modification module for automatic strategy code generation and modification
"""

from .modifier import (
    CodeModifier,
    FileModification,
    CodeContext,
    ModificationResult,
)
from .git_manager import GitManager, VersionInfo
from .code_prompts import CodeGenerationTemplates, StrategyModificationTemplates
from .quality_checker import (
    CodeQualityChecker,
    QualityReport,
    QualityIssue,
)
from .interface_validator import (
    InterfaceValidator,
    InterfaceValidation,
    SignatureChange,
    FunctionSignature,
    ClassSignature,
)

__all__ = [
    # Modifier
    "CodeModifier",
    "FileModification",
    "CodeContext",
    "ModificationResult",
    # Git
    "GitManager",
    "VersionInfo",
    # Prompts
    "CodeGenerationTemplates",
    "StrategyModificationTemplates",
    # Quality
    "CodeQualityChecker",
    "QualityReport",
    "QualityIssue",
    # Interface
    "InterfaceValidator",
    "InterfaceValidation",
    "SignatureChange",
    "FunctionSignature",
    "ClassSignature",
]
